# Random Object Kinematogram

Display oriented objects where a subset moves in a **coherent direction** and/or shares a **coherent orientation**, while the remaining objects move and orient randomly. You can control number of objects and apertures, coherence of motion and orientation, speed, positions, and colors to modulate task difficulty.

## When To Use

- Global motion / orientation coherence detection tasks.
- Manipulating coherence level to adjust difficulty.
- Single- or multi-aperture kinematogram displays.

## Example

Triangles that are rotated in a certain direction and move in a certain direction. 
A percentage of the triangles are rotated randomly and move randomly. 
The more triangles are rotated and moved randomly, 
the harder it is to detect the direction of the majority of the triangles.

![rok](../../img/stimuli/rok.png)

## Notes

Alias: **ROK**